@@ -4,42 +4,42 @@ data_location = os.path.join(__dir__, "verilog")
 src = "https://github.com/openrisc/mor1kx.git"
 
 # Module version
-version_str = "5.0.post170"
-version_tuple = (5, 0, 170)
+version_str = "5.1.post126"
+version_tuple = (5, 1, 126)
 try:
     from packaging.version import Version as V
-    pversion = V("5.0.post170")
+    pversion = V("5.1.post126")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "5.0.post80"
-data_version_tuple = (5, 0, 80)
+data_version_str = "5.1.post2"
+data_version_tuple = (5, 1, 2)
 try:
     from packaging.version import Version as V
-    pdata_version = V("5.0.post80")
+    pdata_version = V("5.1.post2")
 except ImportError:
     pass
-data_git_hash = "a9ac8213d9f752485a6f2bd46885ca37a53899c2"
-data_git_describe = "v5.0-80-ga9ac821"
+data_git_hash = "aca24812520db8e3a0347ac45b0ac18027ccf053"
+data_git_describe = "v5.1-2-gaca2481"
 data_git_msg = """\
-commit a9ac8213d9f752485a6f2bd46885ca37a53899c2
-Merge: dd01358 cf2bce7
+commit aca24812520db8e3a0347ac45b0ac18027ccf053
+Merge: 16ad5ad 698681d
 Author: Stafford Horne <shorne@gmail.com>
-Date:   Fri Jan 1 10:49:08 2021 +0900
+Date:   Wed Jan 12 06:08:22 2022 +0900
 
-    Merge pull request #116 from openrisc/fix-ci
+    Merge pull request #144 from stffrdhrn/synth-params
     
-    travis: Env vars are no longer passed to docker, maybe quotes?
+    core: Add parameters to the synth job
 
 """
 
 # Tool version info
-tool_version_str = "0.0.post90"
-tool_version_tuple = (0, 0, 90)
+tool_version_str = "0.0.post124"
+tool_version_tuple = (0, 0, 124)
 try:
     from packaging.version import Version as V
-    ptool_version = V("0.0.post90")
+    ptool_version = V("0.0.post124")
 except ImportError:
     pass
 
